@@ -1,4 +1,5 @@
 import csv
+import itertools
 import json
 import tempfile
 import os
@@ -56,7 +57,7 @@ def run_task(result_cb, extractor, path):
 def resolve_extractor(extractor):
     return {
         'pos': (EuroparlPoSExtractor, {'pos', 'lemmata', 'regex'}),
-        'perfect': (EuroparlPerfectExtractor, {})}[extractor]
+        'perfect': (EuroparlPerfectExtractor, {'lemmata'})}[extractor]
 
 
 def prepare_query(form, arguments):
@@ -74,6 +75,9 @@ def prepare_query(form, arguments):
                 entries = [entries]
             kwargs[key] = [entry for entry in entries if entry]
 
+    if form.cleaned_data['position']:
+        kwargs['position'] = form.cleaned_data['position']
+
     if any_error:
         return dict(), False
     return kwargs, True
@@ -131,17 +135,13 @@ def csv_to_records(path, limit=10, delimiter=';'):
         except StopIteration:
             return []
 
-        data = []
-        try:
-            data = [next(reader) for i in range(limit)]
-        except StopIteration:
-            pass
+        data = itertools.islice(reader, limit)
         return [dict((headers[i], line[i]) for i in range(len(line))) for line in data]
 
 
 def count_results(path):
     with open(path, encoding='utf-8-sig') as f:
-        return sum(1 for line in f)
+        return sum(1 for line in f) - 1
 
 
 @login_required
@@ -177,3 +177,7 @@ def import_query(request):
     else:
         form = ImportQueryForm()
         return render(request, 'import.html', dict(form=form))
+
+
+def help(request):
+    return render(request, 'help.html')
